@@ -7,9 +7,5 @@ class Converter:
         super().__init__()
 
     @abstractmethod
-    def do(self, **kwargs):
+    def convert(self, **kwargs):
         pass
-
-    def finalize(self, **kwargs):
-        pass
-
